<?php
/**
 * @file Google Analytics (GA) provider for the unitrack tracking subsystem.
 */

function unitrack_ga_settings_form() {
  $form['#redirect'] = 'admin/settings/unitrack';
  
  $current_settings = variable_get('unitrack_ga_settings', FALSE);
  if (!$current_settings) {
  	$current_settings = array(
  	  'primary_account' => 'UA-',
  	  'linkage_enabled' => FALSE,
  	  'linked_domains' => '',
  	  'rollup_account' => '',
  	);
  }
   
  $form['primary_account'] = array(
    '#type' => 'textfield',
    '#title' => t('Google Analytics account number'),
    '#default_value' => $current_settings['primary_account'],
    '#size' => 15,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' => t('Primary account number is unique to the websites domain. Click the <strong>Edit</strong> link in your Google Analytics account next to the appropriate profile on the <strong>Analytics Settings</strong> page, then select <strong>Check Status</strong> at the top-right of the table to find the account number (UA-xxxx-x) of your site. You can obtain a user account from the <a href="@url">Google Analytics</a> website.', array('@url' => 'http://www.google.com/analytics/')),
  );

  $form['linkage'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#title' => t('Account linkage'),
  ); 

  $form['linkage']['linkage_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable'),
    '#description' => t('Enable linkage of several GA accounts.'),
    '#default_value' => $current_settings['linkage_enabled'],
    '#return_value' => '1',
  ); 

  $form['linkage']['linked_domains'] = array(
    '#type' => 'textarea',
    '#title' => t('Linked domains'),
    '#default_value' => $current_settings['linked_domains'],
    '#description' => t('Enter domains that should be linked to the current site, one per line (regular expressions allowed). Outbound links to these domains will be linked to the current site.'),
  ); 
  
  $form['linkage']['rollup_account'] = array(
    '#type' => 'textfield',
    '#title' => t('Roll Up Account'),
    '#default_value' => $current_settings['rollup_account'],
    '#size' => 15,
    '#maxlength' => 20,
    '#description' => t('For reference and instructions, please refer to <a href="@url">Google blog</a>', array('@url' => 'http://analytics.blogspot.com/2009/09/advanced-structure-your-account-with.html')),
  ); 

  $form['submit'] = array(
    '#type' => 'submit', 
    '#value' => t('Save settings'),
  );
  
  return $form;
}

function unitrack_ga_settings_form_submit($form, &$form_state) {
  $new_settings = array(
    'primary_account' => $form_state['values']['primary_account'],
  	'linkage_enabled' => $form_state['values']['linkage_enabled'],
  	'linked_domains' => $form_state['values']['linked_domains'],
  	'rollup_account' => $form_state['values']['rollup_account'],
  );
  variable_set('unitrack_ga_settings', $new_settings);
}