<?php
// $Id: unitrack.admin.inc,v 1.1.2.3 2011/01/30 12:26:50 valthebald Exp $

/**
 * @file
 * Provides the administration page for Unitrack.
 */
  
/**
 * Administration page for UniTrack.
 */
function unitrack_settings_page() {
  return drupal_get_form('unitrack_accounts_overview_form');
  // @todo: enable events form.
  //.drupal_get_form('unitrack_tracking_events_form');
}

function unitrack_accounts_overview_form() {
  $providers = unitrack_get_providers(FALSE, TRUE);
  $accounts = unitrack_get_accounts_list();
  
  $form['general_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
  );
  $form['general_settings']['history_ttl'] = array(
    '#type' => 'textfield',
    '#title' => t('Visitors history storage (days)'),
    '#description' => t('How long to store visitors activity history (in days). 0 means do not store, -1 means store forever (use with care)'),
    '#default_value' => variable_get('unitrack_storage_period', 60),
  );
  
  foreach ($accounts as $id => $types) {
    $form[$id] = array('#type' => 'row');
  	$form[$id]['type'] = array('#value' => $types['type']);
  	$form[$id]['name'] = array('#value' => $types['name']);
  	$form[$id]['configure'] = array('#value' => l(t('Configure'), 'admin/settings/unitrack/account_conf/'. $id));
  	$form[$id]["enabled_{$id}"] = array('#type' => 'checkbox', '#default_value' => $types['enabled']);
  }
  
  $form['submit'] = array('#type' => 'submit', '#value' => t('Apply changes'));
  
  return $form;
}

function unitrack_accounts_overview_form_submit($form, &$form_state) {
  $accounts_list = unitrack_get_accounts_list();
  variable_set('unitrack_storage_period', $form_state['values']['history_ttl']);
  foreach ($accounts_list as $account_id => $account) {
    if($form_state['values']["enabled_{$account_id}"]) {
      db_query('UPDATE {unitrack_types} SET enabled = 1 WHERE id = %d', $account_id);
    } else {
      db_query('UPDATE {unitrack_types} SET enabled = 0 WHERE id = %d', $account_id);
    }
  }
}

function unitrack_tracking_events_form() {
  $events = unitrack_get_events_list();
  $accounts_list = unitrack_get_accounts_list();
  
  $enabled_events = array();
  $result = db_query('SELECT * FROM {unitrack_events}');
  
  while ($enabled_event = db_fetch_object($result)) {
    $enabled_events[$enabled_event->event_id][$enabled_event->type_id] = 1;
  }
  
  foreach ($events as $event_id => $event_name) {
    $form[$event_id] = array('#type' => 'row');
    $form[$event_id]["event_name_{$event_id}"] = array('#value' => $event_name['name']);
    $form[$event_id]['configure'] = array('#value' => l(t('Configure'), 'admin/settings/unitrack/event_conf/'. $event_id));
      
    foreach ($accounts_list as $account_id => $account) {
      $form[$event_id]["cb_{$event_id}_{$account_id}"] = array('#type' => 'checkbox', '#default_value' => isset($enabled_events[$event_id][$account_id]) ? 1 : 0);
    }
  }
  
  $form['submit'] = array('#type' => 'submit', '#value' => t('Enable selected events'));
   
  return $form;
}

function unitrack_tracking_events_form_submit($form, &$form_state) {

  $events = unitrack_get_events_list();
  $accounts_list = unitrack_get_accounts_list();
  
  db_query('DELETE FROM {unitrack_events}');
  
  foreach ($events as $event_id => $event_name) {
    foreach ($accounts_list as $account_id => $account) {
      if($form_state['values']["cb_{$event_id}_{$account_id}"]) {
        db_query('INSERT INTO {unitrack_events} (event_id, type_id) VALUES (%d, %d)', $event_id, $account_id);
      }
    }
  }
}

function unitrack_get_events_list() {
  $events_list = array();
  
  $query = 'SELECT * FROM {unitrack_events_name}';
  $result = db_query($query);
  
  while ($event = db_fetch_object($result)) {
    $events_list[$event->id] = array('name' => $event->name);
  }
  
  return $events_list;
}

function theme_unitrack_accounts_overview_form($form) {
  $rows = array();
  foreach ($form as $id => $element) {
    if (isset($element['#type']) && $element['#type'] == 'row') {
      $rows[] = array(
        drupal_render($element["enabled_{$id}"]),
        drupal_render($element['type']),
        drupal_render($element['name']),
        drupal_render($element['configure']),
      );
      unset($form[$id]);
    }
  }
  $header = array(t('Enabled'), t('Type'), t('Name'), t('Operations'));
  $output = theme('table', $header, $rows);
  $output .= drupal_render($form);

  return $output;
}

function theme_unitrack_tracking_events_form($form) {
  $accounts_list = unitrack_get_accounts_list();
  $header = array(t('Events'));
  $rows = array();
  
  foreach ($accounts_list as $id => $accounts) {
  	$header[] = $accounts['name'];
  }
  
  $header[] = (t('Operations'));
  
  foreach ($form as $id => $element) {
    if (isset($element['#type']) && $element['#type'] == 'row') {
      $row = array($element["event_name_$id"]['#value']);
      foreach ($accounts_list as $account_id => $account) {
        $row[] = drupal_render($element["cb_{$id}_{$account_id}"]);
      }
      $row[] = (drupal_render($element['configure']));
      $rows[] = $row;      
      
      unset($form[$id]);
    }
  }
  
  $output = theme('table', $header, $rows);
  $output .= drupal_render($form);
  
  return $output;
}

function unitrack_get_account_name($account_id) {
  $accounts_list = unitrack_get_accounts_list();
  return $accounts_list[$account_id]['name'];
}

function unitrack_accounts_configuration($account_id) {
  switch ($account_id) {
  	case 1:
  	case 'ga':
  	  require_once drupal_get_path('module', 'unitrack') . '/providers/ga.inc';
      return drupal_get_form('unitrack_ga_settings_form');
  	case 2:
  	case 'clicky':
  	  require_once drupal_get_path('module', 'unitrack') . '/providers/getclicky.inc';
  	  return drupal_get_form('unitrack_getclicky_settings_form');
  }
}
